==> kadu_0.11.0.orig.tar.bz2: kadu-0.11.0/plugins/screenshot/configuration/gui/screenshot-configuration-ui-handler.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <QtGui/QImageWriter>

#include "misc/path-conversion.h"

#include "gui/widgets/configuration/config-combo-box.h"
#include "gui/widgets/configuration/configuration-widget.h"

#include "screenshot-configuration-ui-handler.h"

ScreenShotConfigurationUiHandler *ScreenShotConfigurationUiHandler::Instance = 0;

void ScreenShotConfigurationUiHandler::registerConfigurationUi()
{
	if (Instance)
		return;

	Instance = new ScreenShotConfigurationUiHandler();

	MainConfigurationWindow::registerUiFile(dataPath("kadu/plugins/configuration/screenshot.ui"));
	MainConfigurationWindow::registerUiHandler(Instance);
}

void ScreenShotConfigurationUiHandler::unregisterConfigurationUi()
{
	if (Instance)
		MainConfigurationWindow::unregisterUiHandler(Instance);

	delete Instance;
	Instance = 0;

	MainConfigurationWindow::unregisterUiFile(dataPath("kadu/plugins/configuration/screenshot.ui"));
}

ScreenShotConfigurationUiHandler::ScreenShotConfigurationUiHandler(QObject *parent) :
		ConfigurationUiHandler()
{
	Q_UNUSED(parent)
}

ScreenShotConfigurationUiHandler::~ScreenShotConfigurationUiHandler()
{
}

void ScreenShotConfigurationUiHandler::mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow)
{
	connect(mainConfigurationWindow->widget()->widgetById("screenshot/enableSizeLimit"), SIGNAL(toggled(bool)),
			mainConfigurationWindow->widget()->widgetById("screenshot/sizeLimit"), SLOT(setEnabled(bool)));

	QStringList opts;
	QList<QByteArray> byteArrayOpts = QImageWriter::supportedImageFormats();

	foreach (const QByteArray &opt, byteArrayOpts)
		opts.append(QString(opt));

	ConfigComboBox *formats = static_cast<ConfigComboBox *>(mainConfigurationWindow->widget()->widgetById("screenshot/formats"));
	if (formats)
		formats->setItems(opts, opts);
}

==> kadu_1.1.orig.tar.bz2: kadu-1.1/plugins/screenshot/configuration/gui/screenshot-configuration-ui-handler.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2010, 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <QtGui/QImageWriter>

#include "misc/kadu-paths.h"

#include "gui/widgets/configuration/config-combo-box.h"
#include "gui/widgets/configuration/configuration-widget.h"

#include "screenshot-configuration-ui-handler.h"

ScreenShotConfigurationUiHandler *ScreenShotConfigurationUiHandler::Instance = 0;

void ScreenShotConfigurationUiHandler::registerConfigurationUi()
{
	if (Instance)
		return;

	Instance = new ScreenShotConfigurationUiHandler();

	MainConfigurationWindow::registerUiFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/configuration/screenshot.ui"));
	MainConfigurationWindow::registerUiHandler(Instance);
}

void ScreenShotConfigurationUiHandler::unregisterConfigurationUi()
{
	if (Instance)
		MainConfigurationWindow::unregisterUiHandler(Instance);

	delete Instance;
	Instance = 0;

	MainConfigurationWindow::unregisterUiFile(KaduPaths::instance()->dataPath() + QLatin1String("plugins/configuration/screenshot.ui"));
}

ScreenShotConfigurationUiHandler::ScreenShotConfigurationUiHandler(QObject *parent) :
		ConfigurationUiHandler()
{
	Q_UNUSED(parent)
}

ScreenShotConfigurationUiHandler::~ScreenShotConfigurationUiHandler()
{
}

void ScreenShotConfigurationUiHandler::mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow)
{
	connect(mainConfigurationWindow->widget()->widgetById("screenshot/enableSizeLimit"), SIGNAL(toggled(bool)),
			mainConfigurationWindow->widget()->widgetById("screenshot/sizeLimit"), SLOT(setEnabled(bool)));

	QStringList opts;
	QList<QByteArray> byteArrayOpts = QImageWriter::supportedImageFormats();

	foreach (const QByteArray &opt, byteArrayOpts)
		opts.append(QString(opt));

	ConfigComboBox *formats = static_cast<ConfigComboBox *>(mainConfigurationWindow->widget()->widgetById("screenshot/formats"));
	if (formats)
		formats->setItems(opts, opts);
}

#include "moc_screenshot-configuration-ui-handler.cpp"
